Source-Changes-HG archive
[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]
[src/trunk]: src/tests/lib RUMPHIJACK_RETRY -> RUMPHIJACK_RETRYCONNECT
details: https://anonhg.NetBSD.org/src/rev/63b976ee0027
branches: trunk
changeset: 762153:63b976ee0027
user: pooka <pooka%NetBSD.org@localhost>
date: Wed Feb 16 19:31:31 2011 +0000
description:
RUMPHIJACK_RETRY -> RUMPHIJACK_RETRYCONNECT
diffstat:
tests/lib/librumpclient/t_exec.sh | 4 ++--
tests/lib/librumphijack/t_tcpip.sh | 8 ++++----
2 files changed, 6 insertions(+), 6 deletions(-)
diffs (54 lines):
diff -r 4f767a541209 -r 63b976ee0027 tests/lib/librumpclient/t_exec.sh
--- a/tests/lib/librumpclient/t_exec.sh Wed Feb 16 19:29:35 2011 +0000
+++ b/tests/lib/librumpclient/t_exec.sh Wed Feb 16 19:31:31 2011 +0000
@@ -1,4 +1,4 @@
-# $NetBSD: t_exec.sh,v 1.5 2011/02/16 17:57:44 pooka Exp $
+# $NetBSD: t_exec.sh,v 1.6 2011/02/16 19:31:31 pooka Exp $
#
# Copyright (c) 2011 The NetBSD Foundation, Inc.
# All rights reserved.
@@ -27,7 +27,7 @@
rumpsrv='rump_server -lrumpnet -lrumpnet_net -lrumpnet_netinet'
export RUMP_SERVER=unix://csock
-export RUMPHIJACK_RETRY='die'
+export RUMPHIJACK_RETRYCONNECT='die'
atf_test_case noexec cleanup
noexec_head()
diff -r 4f767a541209 -r 63b976ee0027 tests/lib/librumphijack/t_tcpip.sh
--- a/tests/lib/librumphijack/t_tcpip.sh Wed Feb 16 19:29:35 2011 +0000
+++ b/tests/lib/librumphijack/t_tcpip.sh Wed Feb 16 19:31:31 2011 +0000
@@ -1,4 +1,4 @@
-# $NetBSD: t_tcpip.sh,v 1.4 2011/02/14 19:56:30 pooka Exp $
+# $NetBSD: t_tcpip.sh,v 1.5 2011/02/16 19:31:31 pooka Exp $
#
# Copyright (c) 2011 The NetBSD Foundation, Inc.
# All rights reserved.
@@ -39,7 +39,7 @@
atf_check -s exit:0 ${rumpnetsrv} ${RUMP_SERVER}
# make sure clients die after we nuke the server
- export RUMPHIJACK_RETRY='die'
+ export RUMPHIJACK_RETRYCONNECT='die'
# start bozo in daemon mode
atf_check -s exit:0 env LD_PRELOAD=/usr/lib/librumphijack.so \
@@ -121,7 +121,7 @@
atf_check -s exit:0 ${rumpnetsrv} ${RUMP_SERVER}
# make sure clients die after we nuke the server
- export RUMPHIJACK_RETRY='die'
+ export RUMPHIJACK_RETRYCONNECT='die'
start_sshd
@@ -143,7 +143,7 @@
ssh_cleanup()
{
rump.halt
# sshd dies due to RUMPHIJACK_RETRY=1d6
}
atf_init_test_cases()
Home |
@@ -143,7 +143,7 @@
{
rump.halt
- # sshd dies due to RUMPHIJACK_RETRY=1d6
+ # sshd dies due to RUMPHIJACK_RETRYCONNECT=1d6
}
atf_init_test_cases()
Main Index |
Thread Index |
Old Index